@@ -1,12 +1,17 @@
 package Data::Sah::Coerce::perl::date::str_alami;
 
-our $DATE = '2016-05-27'; # DATE
-our $VERSION = '0.005'; # VERSION
+our $DATE = '2016-06-14'; # DATE
+our $VERSION = '0.006'; # VERSION
 
 use 5.010001;
 use strict;
 use warnings;
 
+use Data::Dmp;
+
+# TMP
+our $time_zone;
+
 sub meta {
     +{
         v => 2,
@@ -25,14 +30,18 @@ sub coerce {
 
     my $res = {};
 
-    unless ($coerce_to eq 'DateTime') {
-        die "To use this coercion rule, you must coerce your date to DateTime (e.g. by adding this attribute 'x.perl.coerce_to' => 'DateTime' to your schema)";
-    }
-
     $res->{expr_match} = "!ref($dt)";
     $res->{modules}{"DateTime::Format::Alami::EN"} //= 0;
     $res->{modules}{"DateTime::Format::Alami::ID"} //= 0;
-    $res->{expr_coerce} = "((\$ENV{LANG} // '') =~ /id_ID/ ? 'DateTime::Format::Alami::ID' : 'DateTime::Format::Alami::EN')->new->parse_datetime($dt)";
+    $res->{expr_coerce} = join(
+        "",
+        "do { my \$res = ((\$ENV{LANG} // '') =~ /id_ID/ ? 'DateTime::Format::Alami::ID' : 'DateTime::Format::Alami::EN')->new->parse_datetime($dt, {_time_zone => ".dmp($time_zone)."}); ",
+        ($coerce_to eq 'float(epoch)' ? "\$res = \$res->epoch; " :
+             $coerce_to eq 'Time::Moment' ? "\$res = Time::Moment->from_object(\$res); " :
+             $coerce_to eq 'DateTime' ? "" :
+             (die "BUG: Unknown coerce_to '$coerce_to'")),
+        "\$res }",
+    );
 
     $res;
 }
@@ -52,7 +61,7 @@ Data::Sah::Coerce::perl::date::str_alami - Coerce date from string parsed by Dat
 
 =head1 VERSION
 
-This document describes version 0.005 of Data::Sah::Coerce::perl::date::str_alami (from Perl distribution Data-Sah-Coerce-perl-date-str_alami), released on 2016-05-27.
+This document describes version 0.006 of Data::Sah::Coerce::perl::date::str_alami (from Perl distribution Data-Sah-Coerce-perl-date-str_alami), released on 2016-06-14.
 
 =head1 DESCRIPTION
 
